@@ -361,7 +361,7 @@ class AslMultiphaseProcess(Script):
         else:
             template = BASIC_YAML
 
-        self._orig_roi = options.pop("roi", None)
+        self._orig_roi = options.pop("roi", "")
         template_params = {
             "data" : data.name,
             "roi" : self._orig_roi,
@@ -376,7 +376,8 @@ class AslMultiphaseProcess(Script):
 
     def finished(self, _):
         """ Called when process finishes """
-        self.ivm.set_current_roi(self._orig_roi)
+        if self._orig_roi:
+            self.ivm.set_current_roi(self._orig_roi)
         self.ivm.set_current_data("mean_mag")
 
 class AslCalibProcess(Process):
@@ -493,6 +494,7 @@ class OxaslProcess(LogProcess):
         self._reportdir = options.pop("report", None)
         self._expected_output = options.pop("output", {})
         self._output_prefix = options.pop("output-prefix", "")
+        self._pvcorr = options.get("pvcorr", False)
 
         oxasl_options = {
             "debug" : self.debug_enabled(),
@@ -548,7 +550,10 @@ class OxaslProcess(LogProcess):
                 self._load_expected_output(self._tempdir, path, name)
 
             # Load 'default' output
-            self._load_default_output(os.path.join(self._tempdir, "output"))
+            if self._pvcorr:
+                self._load_default_output(os.path.join(self._tempdir, "output_pvcorr"))
+            else:
+                self._load_default_output(os.path.join(self._tempdir, "output"))
             self._load_default_output(os.path.join(self._tempdir, "corrected"), suffix="_corr")
             self._load_default_output(os.path.join(self._tempdir, "structural"), suffix="_struc")
             self._load_default_output(os.path.join(self._tempdir, "calibration"), suffix="_calib")
